@@ -13,6 +13,8 @@
 #include <QStandardPaths>
 #include <QUrl>
 
+using namespace Qt::StringLiterals;
+
 UrlHandler::UrlHandler(QObject *parent)
     : QObject(parent)
 {
@@ -21,25 +23,29 @@ UrlHandler::UrlHandler(QObject *parent)
 bool UrlHandler::handleClick(const QUrl &url, QWindow *window)
 {
     QString keyId;
-    if (url.scheme() == QLatin1StringView("key") || url.scheme() == QLatin1StringView("certificate")) {
+    if (url.scheme() == "key"_L1 || url.scheme() == "certificate"_L1) {
         keyId = url.path();
     } else if (!url.hasFragment()) {
         return false;
     }
     QString displayName;
     QString libName;
-    if (keyId.isEmpty() && !foundSMIMEData(url.path() + QLatin1Char('#') + QUrl::fromPercentEncoding(url.fragment().toLatin1()), displayName, libName, keyId)) {
+    if (keyId.isEmpty() && !foundSMIMEData(url.path() + u'#' + QUrl::fromPercentEncoding(url.fragment().toLatin1()), displayName, libName, keyId)) {
         return false;
     }
-    QStringList lst;
-    lst << QStringLiteral("--parent-windowid") << QString::number(static_cast<qlonglong>(window->winId())) << QStringLiteral("--query") << keyId;
+    const QStringList lst{
+        u"--parent-windowid"_s,
+        QString::number(static_cast<qlonglong>(window->winId())),
+        u"--query"_s,
+        keyId,
+    };
 #ifdef Q_OS_WIN
-    QString exec = QStandardPaths::findExecutable(QStringLiteral("kleopatra.exe"), {QCoreApplication::applicationDirPath()});
+    QString exec = QStandardPaths::findExecutable(u"kleopatra.exe"_s, {QCoreApplication::applicationDirPath()});
     if (exec.isEmpty()) {
-        exec = QStandardPaths::findExecutable(QStringLiteral("kleopatra.exe"));
+        exec = QStandardPaths::findExecutable(u"kleopatra.exe"_s);
     }
 #else
-    const QString exec = QStandardPaths::findExecutable(QStringLiteral("kleopatra"));
+    const QString exec = QStandardPaths::findExecutable(u"kleopatra"_s);
 #endif
     if (exec.isEmpty()) {
         qCWarning(MIMETREEPARSER_CORE_LOG) << "Could not find kleopatra executable in PATH";
@@ -52,18 +58,18 @@ bool UrlHandler::handleClick(const QUrl &url, QWindow *window)
 
 bool UrlHandler::foundSMIMEData(const QString &aUrl, QString &displayName, QString &libName, QString &keyId)
 {
-    static QString showCertMan(QStringLiteral("showCertificate#"));
+    static QString showCertMan(u"showCertificate#"_s);
     displayName.clear();
     libName.clear();
     keyId.clear();
     int i1 = aUrl.indexOf(showCertMan);
     if (-1 < i1) {
         i1 += showCertMan.length();
-        int i2 = aUrl.indexOf(QLatin1StringView(" ### "), i1);
+        int i2 = aUrl.indexOf(" ### "_L1, i1);
         if (i1 < i2) {
             displayName = aUrl.mid(i1, i2 - i1);
             i1 = i2 + 5;
-            i2 = aUrl.indexOf(QLatin1StringView(" ### "), i1);
+            i2 = aUrl.indexOf(" ### "_L1, i1);
             if (i1 < i2) {
                 libName = aUrl.mid(i1, i2 - i1);
                 i2 += 5;
