@@ -2,6 +2,7 @@
 // SPDX-License-Identifier: LGPL-2.0-or-later
 
 #include "messageviewer.h"
+using namespace Qt::Literals::StringLiterals;
 
 #include "attachmentview_p.h"
 #include "messagecontainerwidget_p.h"
@@ -36,7 +37,7 @@ using namespace MimeTreeParser::Widgets;
 class MessageViewer::Private
 {
 public:
-    Private(MessageViewer *q_ptr)
+    explicit Private(MessageViewer *q_ptr)
         : q{q_ptr}
         , messageWidget(new KMessageWidget(q_ptr))
     {
@@ -65,17 +66,17 @@ public:
 
     void createActions()
     {
-        saveAttachmentAction = new QAction(QIcon::fromTheme(QStringLiteral("document-save-as-symbolic")), i18n("&Save Attachment As…"), q);
+        saveAttachmentAction = new QAction(QIcon::fromTheme(u"document-save-as-symbolic"_s), i18n("&Save Attachment As…"), q);
         connect(saveAttachmentAction, &QAction::triggered, q, [this]() {
             saveSelectedAttachments();
         });
 
-        openAttachmentAction = new QAction(QIcon::fromTheme(QStringLiteral("document-open-symbolic")), i18nc("to open", "Open"), q);
+        openAttachmentAction = new QAction(QIcon::fromTheme(u"document-open-symbolic"_s), i18nc("to open", "Open"), q);
         connect(openAttachmentAction, &QAction::triggered, q, [this]() {
             openSelectedAttachments();
         });
 
-        importPublicKeyAction = new QAction(QIcon::fromTheme(QStringLiteral("document-import-key-symbolic")), i18nc("@action:inmenu", "Import public key"), q);
+        importPublicKeyAction = new QAction(QIcon::fromTheme(u"document-import-key-symbolic"_s), i18nc("@action:inmenu", "Import public key"), q);
         connect(importPublicKeyAction, &QAction::triggered, q, [this]() {
             importPublicKey();
         });
@@ -368,7 +369,7 @@ void MessageViewer::Private::recursiveBuildViewer(PartModel *parts, QVBoxLayout
 class HeaderLabel : public QLabel
 {
 public:
-    HeaderLabel(const QString &content)
+    explicit HeaderLabel(const QString &content)
         : QLabel(content)
     {
         setWordWrap(true);
